# Copyright 2012, 2013 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from pyramid.view import view_config

from charmworld import cached_view_config
from charmworld.health import (
    check_api,
    check_elasticsearch,
    check_mongodb,
)


# Basic app views
@cached_view_config(
    route_name="home",
    renderer="charmworld:templates/index.pt")
def home(request):
    return {}


@view_config(
    route_name="charmers",
    renderer="charmworld:templates/charmers.pt")
def charmers(request):
    # We want to collect which users have worked on which charms.
    # By worked on means they have at least one commit to it.
    # collect a list of users grouped by charm name.
    # The list of users does not correspond to the lp ids.
    results = request.db.charms.find(
        {}, {"name": 1, 'owner': 1, 'short_url': 1})

    owner_map = {}
    for i in results:
        if not i['owner'] in owner_map:
            owner_map[i['owner']] = 1
        else:
            owner_map[i['owner']] += 1

    owners = owner_map.items()
    owners.sort(lambda x, y: cmp(y[1], x[1]))
    owners.pop(0)
    return {"owners": owners}


@view_config(
    route_name="heartbeat",
    http_cache=(0, {'public': True}),
    renderer="charmworld:templates/heartbeat.pt")
def heartbeat(request):
    """Return a dict summarising the operational state of charmworld."""
    checks = []
    checks.append(check_mongodb(request))
    checks.append(check_elasticsearch(request))
    checks.append(check_api(request))
    return {'checks': checks}
